@@ -14,7 +14,9 @@ use garage_table::*;
 
 use crate::block::*;
 use crate::block_ref_table::*;
+use crate::bucket_alias_table::*;
 use crate::bucket_table::*;
+use crate::helper;
 use crate::key_table::*;
 use crate::object_table::*;
 use crate::version_table::*;
@@ -35,6 +37,8 @@ pub struct Garage {
 
 	/// Table containing informations about buckets
 	pub bucket_table: Arc<Table<BucketTable, TableFullReplication>>,
+	/// Table containing informations about bucket aliases
+	pub bucket_alias_table: Arc<Table<BucketAliasTable, TableFullReplication>>,
 	/// Table containing informations about api keys
 	pub key_table: Arc<Table<KeyTable, TableFullReplication>>,
 
@@ -93,7 +97,6 @@ impl Garage {
 			meta_rep_param.clone(),
 			system.clone(),
 			&db,
-			"block_ref".to_string(),
 		);
 
 		info!("Initialize version_table...");
@@ -105,7 +108,6 @@ impl Garage {
 			meta_rep_param.clone(),
 			system.clone(),
 			&db,
-			"version".to_string(),
 		);
 
 		info!("Initialize object_table...");
@@ -117,26 +119,21 @@ impl Garage {
 			meta_rep_param,
 			system.clone(),
 			&db,
-			"object".to_string(),
 		);
 
 		info!("Initialize bucket_table...");
-		let bucket_table = Table::new(
-			BucketTable,
+		let bucket_table = Table::new(BucketTable, control_rep_param.clone(), system.clone(), &db);
+
+		info!("Initialize bucket_alias_table...");
+		let bucket_alias_table = Table::new(
+			BucketAliasTable,
 			control_rep_param.clone(),
 			system.clone(),
 			&db,
-			"bucket".to_string(),
 		);
 
 		info!("Initialize key_table_table...");
-		let key_table = Table::new(
-			KeyTable,
-			control_rep_param,
-			system.clone(),
-			&db,
-			"key".to_string(),
-		);
+		let key_table = Table::new(KeyTable, control_rep_param, system.clone(), &db);
 
 		info!("Initialize Garage...");
 		let garage = Arc::new(Self {
@@ -146,6 +143,7 @@ impl Garage {
 			system,
 			block_manager,
 			bucket_table,
+			bucket_alias_table,
 			key_table,
 			object_table,
 			version_table,
@@ -163,4 +161,8 @@ impl Garage {
 	pub fn break_reference_cycles(&self) {
 		self.block_manager.garage.swap(None);
 	}
+
+	pub fn bucket_helper(&self) -> helper::bucket::BucketHelper {
+		helper::bucket::BucketHelper(self)
+	}
 }
