@@ -1,10 +1,17 @@
 #[macro_use]
 extern crate log;
 
-pub mod block;
+pub mod permission;
+
 pub mod block_ref_table;
+pub mod bucket_alias_table;
 pub mod bucket_table;
-pub mod garage;
 pub mod key_table;
 pub mod object_table;
 pub mod version_table;
+
+pub mod block;
+
+pub mod garage;
+pub mod helper;
+pub mod migrate;
